# BSD 3-Clause "New" or "Revised" License (BSD-3-Clause) 
# Copyright (c) 2020 Stephen McCalman. All rights reserved.

"""
A Python client package for accessing data from an API that follows the Consumer Data Standards (CDS).
CDS repo: https://consumerdatastandardsaustralia.github.io/standards

Generated with the Swagger-Codegen CLI from a Swagger specification file of the Consumer Data Standards.
Do not edit this file manually. CLI repo: https://github.com/swagger-api/swagger-codegen
    
The package is NOT part of the official Consumer Data Standards' project nor any API implementation of the Standards.
Package repo: https://github.com/stephenmccalman/cds-python-api-client
"""


import pprint
import re  # noqa: F401

class BankingProductFeature(object):
    """BankingProductFeature class."""
    


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'feature_type': 'str',
        'additional_value': 'str',
        'additional_info': 'str',
        'additional_info_uri': 'str'
    }

    attribute_map = {
        'feature_type': 'featureType',
        'additional_value': 'additionalValue',
        'additional_info': 'additionalInfo',
        'additional_info_uri': 'additionalInfoUri'
    }

    def __init__(self, feature_type=None, additional_value=None, additional_info=None, additional_info_uri=None):  # noqa: E501
        """BankingProductFeature"""  # noqa: E501

        self._feature_type = None
        self._additional_value = None
        self._additional_info = None
        self._additional_info_uri = None
        self.discriminator = None

        self.feature_type = feature_type
        if additional_value is not None:
            self.additional_value = additional_value
        if additional_info is not None:
            self.additional_info = additional_info
        if additional_info_uri is not None:
            self.additional_info_uri = additional_info_uri

    @property
    def feature_type(self):
        """Gets the feature_type of this BankingProductFeature.  # noqa: E501

        The type of feature described  # noqa: E501

        :return: The feature_type of this BankingProductFeature.  # noqa: E501
        :rtype: str
        """
        return self._feature_type

    @feature_type.setter
    def feature_type(self, feature_type):
        """Sets the feature_type of this BankingProductFeature.

        The type of feature described  # noqa: E501

        :param feature_type: The feature_type of this BankingProductFeature.  # noqa: E501
        :type: str
        """
        if feature_type is None:
            raise ValueError("Invalid value for `feature_type`, must not be `None`")  # noqa: E501
        allowed_values = ["CARD_ACCESS", "ADDITIONAL_CARDS", "UNLIMITED_TXNS", "FREE_TXNS", "FREE_TXNS_ALLOWANCE", "LOYALTY_PROGRAM", "OFFSET", "OVERDRAFT", "REDRAW", "INSURANCE", "BALANCE_TRANSFERS", "INTEREST_FREE", "INTEREST_FREE_TRANSFERS", "DIGITAL_WALLET", "DIGITAL_BANKING", "NPP_PAYID", "NPP_ENABLED", "DONATE_INTEREST", "BILL_PAYMENT", "COMPLEMENTARY_PRODUCT_DISCOUNTS", "BONUS_REWARDS", "NOTIFICATIONS", "OTHER"]  # noqa: E501
        if feature_type not in allowed_values:
            raise ValueError(
                "Invalid value for `feature_type` ({0}), must be one of {1}"  # noqa: E501
                .format(feature_type, allowed_values)
            )

        self._feature_type = feature_type

    @property
    def additional_value(self):
        """Gets the additional_value of this BankingProductFeature.  # noqa: E501

        Generic field containing additional information relevant to the [featureType](#tocSproductfeaturetypedoc) specified. Whether mandatory or not is dependent on the value of the [featureType.](#tocSproductfeaturetypedoc)  # noqa: E501

        :return: The additional_value of this BankingProductFeature.  # noqa: E501
        :rtype: str
        """
        return self._additional_value

    @additional_value.setter
    def additional_value(self, additional_value):
        """Sets the additional_value of this BankingProductFeature.

        Generic field containing additional information relevant to the [featureType](#tocSproductfeaturetypedoc) specified. Whether mandatory or not is dependent on the value of the [featureType.](#tocSproductfeaturetypedoc)  # noqa: E501

        :param additional_value: The additional_value of this BankingProductFeature.  # noqa: E501
        :type: str
        """

        self._additional_value = additional_value

    @property
    def additional_info(self):
        """Gets the additional_info of this BankingProductFeature.  # noqa: E501

        Display text providing more information on the feature. Mandatory if the [feature type](#tocSproductfeaturetypedoc) is set to OTHER  # noqa: E501

        :return: The additional_info of this BankingProductFeature.  # noqa: E501
        :rtype: str
        """
        return self._additional_info

    @additional_info.setter
    def additional_info(self, additional_info):
        """Sets the additional_info of this BankingProductFeature.

        Display text providing more information on the feature. Mandatory if the [feature type](#tocSproductfeaturetypedoc) is set to OTHER  # noqa: E501

        :param additional_info: The additional_info of this BankingProductFeature.  # noqa: E501
        :type: str
        """

        self._additional_info = additional_info

    @property
    def additional_info_uri(self):
        """Gets the additional_info_uri of this BankingProductFeature.  # noqa: E501

        Link to a web page with more information on this feature  # noqa: E501

        :return: The additional_info_uri of this BankingProductFeature.  # noqa: E501
        :rtype: str
        """
        return self._additional_info_uri

    @additional_info_uri.setter
    def additional_info_uri(self, additional_info_uri):
        """Sets the additional_info_uri of this BankingProductFeature.

        Link to a web page with more information on this feature  # noqa: E501

        :param additional_info_uri: The additional_info_uri of this BankingProductFeature.  # noqa: E501
        :type: str
        """

        self._additional_info_uri = additional_info_uri

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in self.swagger_types.items():
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(BankingProductFeature, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BankingProductFeature):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
