# BSD 3-Clause "New" or "Revised" License (BSD-3-Clause) 
# Copyright (c) 2020 Stephen McCalman. All rights reserved.

"""
A Python client package for accessing data from an API that follows the Consumer Data Standards (CDS).
CDS repo: https://consumerdatastandardsaustralia.github.io/standards

Generated with the Swagger-Codegen CLI from a Swagger specification file of the Consumer Data Standards.
Do not edit this file manually. CLI repo: https://github.com/swagger-api/swagger-codegen
    
The package is NOT part of the official Consumer Data Standards' project nor any API implementation of the Standards.
Package repo: https://github.com/stephenmccalman/cds-python-api-client
"""


import pprint
import re  # noqa: F401

class CommonEmailAddress(object):
    """CommonEmailAddress class."""
    


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'is_preferred': 'bool',
        'purpose': 'str',
        'address': 'str'
    }

    attribute_map = {
        'is_preferred': 'isPreferred',
        'purpose': 'purpose',
        'address': 'address'
    }

    def __init__(self, is_preferred=None, purpose=None, address=None):  # noqa: E501
        """CommonEmailAddress"""  # noqa: E501

        self._is_preferred = None
        self._purpose = None
        self._address = None
        self.discriminator = None

        if is_preferred is not None:
            self.is_preferred = is_preferred
        self.purpose = purpose
        self.address = address

    @property
    def is_preferred(self):
        """Gets the is_preferred of this CommonEmailAddress.  # noqa: E501

        May be true for one and only one email record in the collection. Denotes the default email address  # noqa: E501

        :return: The is_preferred of this CommonEmailAddress.  # noqa: E501
        :rtype: bool
        """
        return self._is_preferred

    @is_preferred.setter
    def is_preferred(self, is_preferred):
        """Sets the is_preferred of this CommonEmailAddress.

        May be true for one and only one email record in the collection. Denotes the default email address  # noqa: E501

        :param is_preferred: The is_preferred of this CommonEmailAddress.  # noqa: E501
        :type: bool
        """

        self._is_preferred = is_preferred

    @property
    def purpose(self):
        """Gets the purpose of this CommonEmailAddress.  # noqa: E501

        The purpose for the email, as specified by the customer (Enumeration)  # noqa: E501

        :return: The purpose of this CommonEmailAddress.  # noqa: E501
        :rtype: str
        """
        return self._purpose

    @purpose.setter
    def purpose(self, purpose):
        """Sets the purpose of this CommonEmailAddress.

        The purpose for the email, as specified by the customer (Enumeration)  # noqa: E501

        :param purpose: The purpose of this CommonEmailAddress.  # noqa: E501
        :type: str
        """
        if purpose is None:
            raise ValueError("Invalid value for `purpose`, must not be `None`")  # noqa: E501
        allowed_values = ["WORK", "HOME", "OTHER", "UNSPECIFIED"]  # noqa: E501
        if purpose not in allowed_values:
            raise ValueError(
                "Invalid value for `purpose` ({0}), must be one of {1}"  # noqa: E501
                .format(purpose, allowed_values)
            )

        self._purpose = purpose

    @property
    def address(self):
        """Gets the address of this CommonEmailAddress.  # noqa: E501

        A correctly formatted email address, as defined by the addr_spec format in [RFC 5322](https://www.ietf.org/rfc/rfc5322.txt)  # noqa: E501

        :return: The address of this CommonEmailAddress.  # noqa: E501
        :rtype: str
        """
        return self._address

    @address.setter
    def address(self, address):
        """Sets the address of this CommonEmailAddress.

        A correctly formatted email address, as defined by the addr_spec format in [RFC 5322](https://www.ietf.org/rfc/rfc5322.txt)  # noqa: E501

        :param address: The address of this CommonEmailAddress.  # noqa: E501
        :type: str
        """
        if address is None:
            raise ValueError("Invalid value for `address`, must not be `None`")  # noqa: E501

        self._address = address

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in self.swagger_types.items():
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CommonEmailAddress, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CommonEmailAddress):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
