# BSD 3-Clause "New" or "Revised" License (BSD-3-Clause) 
# Copyright (c) 2020 Stephen McCalman. All rights reserved.

"""
A Python client package for accessing data from an API that follows the Consumer Data Standards (CDS).
CDS repo: https://consumerdatastandardsaustralia.github.io/standards

Generated with the Swagger-Codegen CLI from a Swagger specification file of the Consumer Data Standards.
Do not edit this file manually. CLI repo: https://github.com/swagger-api/swagger-codegen
    
The package is NOT part of the official Consumer Data Standards' project nor any API implementation of the Standards.
Package repo: https://github.com/stephenmccalman/cds-python-api-client
"""


import pprint
import re  # noqa: F401

class DiscoveryOutage(object):
    """DiscoveryOutage class."""
    


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'outage_time': 'str',
        'duration': 'str',
        'is_partial': 'bool',
        'explanation': 'str'
    }

    attribute_map = {
        'outage_time': 'outageTime',
        'duration': 'duration',
        'is_partial': 'isPartial',
        'explanation': 'explanation'
    }

    def __init__(self, outage_time=None, duration=None, is_partial=None, explanation=None):  # noqa: E501
        """DiscoveryOutage"""  # noqa: E501

        self._outage_time = None
        self._duration = None
        self._is_partial = None
        self._explanation = None
        self.discriminator = None

        self.outage_time = outage_time
        self.duration = duration
        if is_partial is not None:
            self.is_partial = is_partial
        self.explanation = explanation

    @property
    def outage_time(self):
        """Gets the outage_time of this DiscoveryOutage.  # noqa: E501

        Date and time that the outage is scheduled to begin  # noqa: E501

        :return: The outage_time of this DiscoveryOutage.  # noqa: E501
        :rtype: str
        """
        return self._outage_time

    @outage_time.setter
    def outage_time(self, outage_time):
        """Sets the outage_time of this DiscoveryOutage.

        Date and time that the outage is scheduled to begin  # noqa: E501

        :param outage_time: The outage_time of this DiscoveryOutage.  # noqa: E501
        :type: str
        """
        if outage_time is None:
            raise ValueError("Invalid value for `outage_time`, must not be `None`")  # noqa: E501

        self._outage_time = outage_time

    @property
    def duration(self):
        """Gets the duration of this DiscoveryOutage.  # noqa: E501

        Planned duration of the outage. Formatted according to [ISO 8601 Durations](https://en.wikipedia.org/wiki/ISO_8601#Durations) (excludes recurrence syntax)  # noqa: E501

        :return: The duration of this DiscoveryOutage.  # noqa: E501
        :rtype: str
        """
        return self._duration

    @duration.setter
    def duration(self, duration):
        """Sets the duration of this DiscoveryOutage.

        Planned duration of the outage. Formatted according to [ISO 8601 Durations](https://en.wikipedia.org/wiki/ISO_8601#Durations) (excludes recurrence syntax)  # noqa: E501

        :param duration: The duration of this DiscoveryOutage.  # noqa: E501
        :type: str
        """
        if duration is None:
            raise ValueError("Invalid value for `duration`, must not be `None`")  # noqa: E501

        self._duration = duration

    @property
    def is_partial(self):
        """Gets the is_partial of this DiscoveryOutage.  # noqa: E501

        Flag that indicates, if present and set to true, that the outage is only partial meaning that only a subset of normally available end points will be affected by the outage  # noqa: E501

        :return: The is_partial of this DiscoveryOutage.  # noqa: E501
        :rtype: bool
        """
        return self._is_partial

    @is_partial.setter
    def is_partial(self, is_partial):
        """Sets the is_partial of this DiscoveryOutage.

        Flag that indicates, if present and set to true, that the outage is only partial meaning that only a subset of normally available end points will be affected by the outage  # noqa: E501

        :param is_partial: The is_partial of this DiscoveryOutage.  # noqa: E501
        :type: bool
        """

        self._is_partial = is_partial

    @property
    def explanation(self):
        """Gets the explanation of this DiscoveryOutage.  # noqa: E501

        Provides an explanation of the current outage that can be displayed to an end customer  # noqa: E501

        :return: The explanation of this DiscoveryOutage.  # noqa: E501
        :rtype: str
        """
        return self._explanation

    @explanation.setter
    def explanation(self, explanation):
        """Sets the explanation of this DiscoveryOutage.

        Provides an explanation of the current outage that can be displayed to an end customer  # noqa: E501

        :param explanation: The explanation of this DiscoveryOutage.  # noqa: E501
        :type: str
        """
        if explanation is None:
            raise ValueError("Invalid value for `explanation`, must not be `None`")  # noqa: E501

        self._explanation = explanation

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in self.swagger_types.items():
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DiscoveryOutage, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DiscoveryOutage):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
